#!/bin/bash

VERSION=0.4
DEST=$1
SERVICE=$2
DONTPING=""
DONTSHOWOS="0"
DONTSHOWVERSION="0"

function header {
  echo "Arb-Scan Version $VERSION"
  echo "--------------------"
}

function usage {
  header
  echo "Usage: $0 <ip|hostname> <none|service|all>"
  echo " "
  echo "Help: <ip|hostname>		- enter a ip address or a hostname"
  echo "      <none|service|all>	- enter only one service(doc/SERVICES),"
  echo "                                  or \"all\" to scan all services,"
  echo "				  or \"none\" to scan none service"
  echo "      [<-ping>]			- ping host not before scan,"
  echo "				  default is to ping the host"
  echo "      [<-showos>]		- show not the remote os,"
  echo "				  default is to show the os"
  echo "      [<-version>]		- show not the version of arb-scan,"
  echo "				  default is to show the version"       
}

function scan {
  if [ "$DONTSHOWVERSION" = "0" ]; then
    header
  fi
  echo "- start scan of $DEST"
}

function check_all {
  scripts/./scan-nmap-all.sh $DEST $DONTPING
  scripts/./check-ftp.sh $DEST
  scripts/./check-ssh.sh $DEST
  scripts/./check-smtp.sh $DEST
  scripts/./check-domain.sh $DEST
  scripts/./check-finger.sh $DEST
  scripts/./check-http.sh $DEST
  scripts/./check-pop2.sh $DEST
  scripts/./check-pop3.sh $DEST
  scripts/./check-imap.sh $DEST
}

if [ "$DEST" = "" ]; then
  usage
  exit 1
fi

case $3 in
  	-ping)		DONTPING="-P0"	
			;;
        -showos)	DONTSHOWOS="1"
			;;
        -version)	DONTSHOWVERSION="1"
			;;
esac

case $4 in
  	-ping)		DONTPING="-P0"
			;;
        -showos)	DONTSHOWOS="1"
			;;
        -version)	DONTSHOWVERSION="1"
			;;
esac

case $5 in
  	-ping)		DONTPING="-P0"
			;;
        -showos)	DONTSHOWOS="1"
			;;
        -version)	DONTSHOWVERSION="1"
			;;
esac

case "$SERVICE" in
        ftp)		 scan
                         scripts/./scan-nmap-service.sh $DEST 21 $DONTPING
                         scripts/./check-ftp.sh $DEST
                         echo "- end of scan"
	                 ;;
	ssh)		 scan
                         scripts/./scan-nmap-service.sh $DEST 22 $DONTPING
                         scripts/./check-ssh.sh $DEST
                         echo "- end of scan"
	                 ;;
	smtp)		 scan
                         scripts/./scan-nmap-service.sh $DEST 25 $DONTPING
                         scripts/./check-smtp.sh $DEST
                         echo "- end of scan"
	                 ;;
	domain)		 scan
                         scripts/./scan-nmap-service.sh $DEST 53 $DONTPING
                         scripts/./check-domain.sh $DEST
                         echo "- end of scan"
	                 ;;
	finger)		 scan
                         scripts/./scan-nmap-service.sh $DEST 79 $DONTPING
                         scripts/./check-finger.sh $DEST
                         echo "- end of scan"
	                 ;;
	http)		 scan                         
			 scripts/./scan-nmap-service.sh $DEST 80 $DONTPING
                         scripts/./check-http.sh $DEST
                         echo "- end of scan"
	                 ;;
	pop2)		 scan
                         scripts/./scan-nmap-service.sh $DEST 109 $DONTPING
                         scripts/./check-pop2.sh $DEST
                         echo "- end of scan"
	                 ;;
	pop3)		 scan
                         scripts/./scan-nmap-service.sh $DEST 110 $DONTPING
                         scripts/./check-pop3.sh $DEST
                         echo "- end of scan"
	                 ;;
	imap)		 scan
                         scripts/./scan-nmap-service.sh $DEST 143 $DONTPING
                         scripts/./check-imap.sh $DEST
                         echo "- end of scan"
	                 ;;
	all)             scan
                         check_all
                         echo "- end of scan"
        	         ;;
        none)		 scan
                         scripts/./scan-nmap-all.sh $DEST $DONTPING
                         echo "- end of scan"
                         ;;
        *)		 usage
                         DONTSHOWOS="1"
                         ;;
esac

if [ "$DONTSHOWOS" = "0" ]; then
  OS=`cat log/scan-$DEST.log | grep Remote | cut -b 32-80`
  if [ "$OS" ]; then
    echo "- Remote OS: $OS..."
  fi
  if [ "$OS" = "" ]; then
    echo "- no OS found"
  fi
fi

